import { Connection, PublicKey, Signer, Transaction, TransactionInstruction } from '@solana/web3.js';
import { Jupiter, RouteInfo } from '@jup-ag/core';
/**
 * SwapToLP class for swapping SPL tokens to LP tokens through rebalancing and staking.
 */
export declare class SwapToLP {
    /**
     * Properties
     */
    connection: Connection;
    jupiter: Jupiter;
    /**
     * Constructor for the SwapToLP class. Builds and returns a SwapToLP object.
     */
    private constructor();
    /**
     * Initializes a SwapToLP object.
     */
    static build(connection: Connection, user: PublicKey): Promise<SwapToLP>;
    /**
     * Generates a set of unsigned transactions for swapping a single SPL token to base/quote tokens required for LP. The transactions include setup transactions for the output tokens based on the LP token's base and quote mints.
     * @param inputTokenAmount - raw amount to swap
     * @param inputTokenMint - mint of token to swap
     * @param lpTokenMint - mint of lp token to receive
     * @param liquidityPoolVenue - venue of liquidity pool
     * @param slippageTolerancePercent - slippage tolerance in percent, between 0 and 100
     */
    private _swap;
    /**
     * Generate a transaction to add liquidity to a Raydium LP and if required to open the LP token account.
     * @param lpTokenMint - mint of lp token to receive
     * @param poolInfo - Raydium pool info
     * @param tokenAAmount - raw amount of base token to stake in LP
     * @param user - Public key of owner of LP token account
     * @param connection - web.js connection
     * @param addLiquiditySlippagePercent - slippage tolerance for adding liquidity in percent, between 0 and 100
     */
    private _createAddLiquidityRaydiumTx;
    /**
     * Generate a transaction to add liquidity to an Orca LP and if required to open the LP token account.
     * @param lpTokenMint - mint of lp token to receive
     * @param poolInfo - Orce pool info
     * @param tokenAAmount - raw amount of base token to stake in LP
     * @param tokenBAmount - raw amount of quote token to stake in LP
     * @param user - Public key of owner of LP token account
     * @param connection - web.js connection
     */
    private _createAddLiquidityOrcaTx;
    /**
     * Helper method to bundling `swapToBaseQuote` and `addLiquidity` together.
     * @param inputTokenAmount - raw amount to swap
     * @param inputTokenMint - mint of token to swap
     * @param lpTokenMint - mint of lp token to receive
     * @returns Array of transactions
     */
    swapAndAddLiquidity(inputTokenAmount: number, inputTokenMint: PublicKey, lpTokenMint: PublicKey, user: PublicKey, connection?: Connection, liquidityPoolVenue?: LiquidityPoolVenues): Promise<{
        swapTransactions: Transaction[];
        addLiquidityTransaction: TransactionWrapper;
        routes: {
            baseRoute: RouteInfo;
            quoteRoute: RouteInfo;
        };
        prices: {
            inputTokenPrice: number;
            basePrice: number;
            quotePrice: number;
        };
        tokenInfo: {
            inputTokenInfo: any;
            baseInfo: any;
            quoteInfo: any;
        };
    }>;
    /**
     * Get route info.
     * @param inputTokenAmount - raw amount to swap
     * @param inputTokenMint - mint of token to swap
     * @param lpTokenMint - mint of lp token to receive
     * @param liquidityPoolVenue - venue of liquidity pool
     */
    getRouteInfo(inputTokenAmount: number, inputTokenMint: PublicKey, lpTokenMint: PublicKey, liquidityPoolVenue?: LiquidityPoolVenues): Promise<{
        baseRoute: RouteInfo;
        quoteRoute: RouteInfo;
    }>;
    /**
     * Get pool info for Raydium LP token mint.
     * @param lpTokenMint - LP token mint
     */
    private _getRaydiumPoolInfo;
    /**
     * Get pool info for Orca LP token mint.
     * @param lpTokenMint - LP token mint
     */
    private _getOrcaPoolInfo;
    /**
     * Get token info for a given mint.
     * @param tokenMint - token mint
     */
    private _getTokenInfo;
    /**
     * Get token price for a given mint.
     * @param tokenMint - mint of token price to lookup
     * @param tokenDecimals - token decimals
     */
    getJupiterTokenPrice(tokenMint: string, tokenDecimals: number): Promise<number>;
}
export interface IUserBalances {
    tokenAAddress: PublicKey;
    tokenABalance: number;
    tokenBAddress: PublicKey;
    tokenBBalance: number;
    lpTokenAddress: PublicKey;
    lpTokenBalance: number;
}
export interface AddLiquidityIxs {
    createTokenAccountInstruction?: TransactionInstruction;
    addLiquidityInstruction: TransactionInstruction;
}
export declare enum LiquidityPoolVenues {
    RAYDIUM = "RAYDIUM",
    ORCA = "ORCA"
}
export interface TransactionWrapper {
    transaction: Transaction;
    signers?: Signer[];
}
